#
# Cookbook Name:: ls_windows_ad
# Recipe:: create_domain
#
# Copyright (c) 2016 The Authors, All Rights Reserved.

windows_feature 'AD-Domain-Services' do
  action :install
  all true
  provider :windows_feature_powershell
end

windows_feature 'RSAT-AD-Tools' do
  action :install
  all true
  provider :windows_feature_powershell
end

windows_feature 'RSAT-ADDS' do
  action :install
  all true
  provider :windows_feature_powershell
end

# Reboot resource
reboot 'Restart Computer' do
  action :nothing
end

# Retry Variables TODO set in default for overides as necessary
# retry_count = 15
# retry_interval_secs = 10

if node['ls_windows_ad']['role'] == 'primary'
  powershell_script 'Install-NewForest' do
    code <<-EOH
      Import-Module ADDSDeployment
      $SafeModePswd = ConvertTo-SecureString '#{node['ls_windows_ad']['safe_mode_admin_pswd']}' -AsPlainText -Force
      Install-ADDSForest `
        -CreateDnsDelegation:$false `
        -DatabasePath "C:\Windows\NTDS" `
        -DomainName "#{node['ls_windows_ad']['domain_name']}" `
        -DomainNetbiosName "#{node['ls_windows_ad']['domain_netbios_name']}" `
        -ForestMode "#{node['ls_windows_ad']['version']}" `
        -InstallDns:$true `
        -LogPath "C:\Windows\NTDS" `
        -SysvolPath "C:\Windows\SYSVOL" `
        -SafeModeAdministratorPassword $SafeModePswd `
        -NoRebootOnCompletion:$true `
        -Force:$true
    EOH
    guard_interpreter :powershell_script
    only_if <<-EOH
      try{
        Import-Module ActiveDirectory
        $adminpswd = ConvertTo-SecureString '#{node['ls_windows_ad']['admin_pswd']}' -AsPlainText -Force
        $credential = New-Object System.Management.Automation.PSCredential ("#{node['ls_windows_ad']['admin_username']}",$adminpswd)
        $domain = Get-ADDomain -Identity #{node['ls_windows_ad']['domain_name']} -Credential $credential
      }
      catch{
      }
      $domain -eq $null
    EOH
    notifies :reboot_now, 'reboot[Restart Computer]', :immediately
  end
end

if node['ls_windows_ad']['role'] == 'replica'
  powershell_script 'Install-DomainController' do
    code <<-EOH
      $SafeModePswd = ConvertTo-SecureString '#{node['ls_windows_ad']['safe_mode_admin_pswd']}' -AsPlainText -Force
      $adminpswd = ConvertTo-SecureString '#{node['ls_windows_ad']['admin_pswd']}' -AsPlainText -Force
      $credential = New-Object System.Management.Automation.PSCredential ("#{node['ls_windows_ad']['admin_username']}",$adminpswd) 
      Import-Module ADDSDeployment
      Install-ADDSDomainController `
        -NoGlobalCatalog:$false `
        -CreateDnsDelegation:$false `
        -Credential $credential `
        -CriticalReplicationOnly:$false `
        -DatabasePath "C:\WINDOWS\NTDS" `
        -DomainName "#{node['ls_windows_ad']['domain_name']}" `
        -InstallDns:$true `
        -LogPath "C:\WINDOWS\NTDS" `
        -NoRebootOnCompletion:$true `
        -SysvolPath "C:\WINDOWS\SYSVOL" `
        -SafeModeAdministratorPassword $SafeModePswd `
        -Force:$true `
        -Confirm:$false
    EOH
    guard_interpreter :powershell_script
    only_if <<-EOH
      $returnValue = $true
      try{
          Import-Module ActiveDirectory
          $adminpswd = ConvertTo-SecureString '#{node['ls_windows_ad']['admin_pswd']}' -AsPlainText -Force
          $credential = New-Object System.Management.Automation.PSCredential ("#{node['ls_windows_ad']['admin_username']}",$adminpswd)
          $domain = Get-ADDomain -Identity #{node['ls_windows_ad']['domain_name']} -Credential $credential
          if($domain -ne $null){
              $dc = Get-ADDomainController -Identity $env:COMPUTERNAME -Credential $credential
              if($dc.Domain -eq "#{node['ls_windows_ad']['domain_name']}"){
                  $returnValue = $false
              }
          }
          else{
              $domainFound = $false
              for($count - 0; $count -lt 15; $count++){
                  try{
                      $domain = Get-ADDomain -Identity #{node['ls_windows_ad']['domain_name']} -Credential $credential
                      $domainFound = $true
                      break;
                  }
                  catch{
                      Start-Sleep -Seconds 10
                  }
              }
              if($domain -ne $null){
                  $dc = Get-ADDomainController -Identity $env:COMPUTERNAME -Credential $credential
                  if($dc.Domain -eq "#{node['ls_windows_ad']['domain_name']}"){
                      $returnValue = $false
                  }
              }
          }
      }
      catch{}
      $returnValue
    EOH
    notifies :reboot_now, 'reboot[Restart Computer]', :immediately
  end
end

